@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
 version: 1.3.3.1
-id: authenticate-1.3.3.1-de5806f9d15beccb070a770364a3018e
-key: authe_HGus0ePTHs6JUjzx5oAJ1H
+id: authenticate-1.3.3.1-92c2920e5f9105fbbfe3ef7e611db03b
+key: authe_DAu8l702iZ2FC4jUBSZI05
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,26 +23,26 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3.1
-hs-libraries: HSauthenticate-1.3.3.1-HGus0ePTHs6JUjzx5oAJ1H
+hs-libraries: HSauthenticate-1.3.3.1-DAu8l702iZ2FC4jUBSZI05
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    http-conduit-2.1.10-ea6ea22a5cbf3da5e7b57316d38129f0
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
-    tagstream-conduit-0.5.5.3-263ed71b63ed196273744e4745b0360d
+    tagstream-conduit-0.5.5.3-4b98929de5740d25f2891082b83d8e10
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
+    xml-conduit-1.3.4.2-23ea4c09fbb2f125e079f8ce359b7189
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
